@@ -1,7 +1,7 @@
 /* -*-mode:c; c-style:k&r; c-basic-offset:4; -*- */
 /* Balsa E-Mail Client
  *
- * Copyright (C) 1997-2005 Stuart Parmenter and others,
+ * Copyright (C) 1997-2009 Stuart Parmenter and others,
  *                         See the file AUTHORS for a list.
  *
  * Rubrica2 address book support was written by Copyright (C)
@@ -27,7 +27,10 @@
  * A Rubrica (XML) addressbook.
  */
 
-#include "config.h"
+#if defined(HAVE_CONFIG_H) && HAVE_CONFIG_H
+# include "config.h"
+#endif                          /* HAVE_CONFIG_H */
+#include "address-book-rubrica.h"
 
 #if HAVE_RUBRICA
 
@@ -35,12 +38,12 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
+#include <unistd.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 #include "libbalsa-conf.h"
 #include "abook-completion.h"
 #include "misc.h"
-#include "address-book-rubrica.h"
 #include <glib/gi18n.h>
 
 
@@ -60,8 +63,7 @@ static LibBalsaABErr libbalsa_address_book_rubrica_load(LibBalsaAddressBook
 							gpointer data);
 static GList
     *libbalsa_address_book_rubrica_alias_complete(LibBalsaAddressBook * ab,
-						  const gchar * prefix,
-						  char **new_prefix);
+						  const gchar * prefix);
 static LibBalsaABErr
 libbalsa_address_book_rubrica_add_address(LibBalsaAddressBook * ab,
 					  LibBalsaAddress * new_address);
@@ -128,8 +130,9 @@ libbalsa_address_book_rubrica_init(LibBalsaAddressBookRubrica * ab_rubrica)
     ab_text->mtime = 0;
 
     ab_text->name_complete =
-	g_completion_new((GCompletionFunc) completion_data_extract);
-    g_completion_set_compare(ab_text->name_complete, strncmp_word);
+        libbalsa_completion_new((LibBalsaCompletionFunc)
+                                completion_data_extract);
+    libbalsa_completion_set_compare(ab_text->name_complete, strncmp_word);
 }
 
 static void
@@ -217,27 +220,26 @@ libbalsa_address_book_rubrica_load(LibBalsaAddressBook * ab,
 /* Alias complete method */
 static GList *
 libbalsa_address_book_rubrica_alias_complete(LibBalsaAddressBook * ab,
-					     const gchar * prefix,
-					     char **new_prefix)
+					     const gchar * prefix)
 {
     LibBalsaAddressBookRubrica *ab_rubrica =
-	LIBBALSA_ADDRESS_BOOK_RUBRICA(ab);
+        LIBBALSA_ADDRESS_BOOK_RUBRICA(ab);
     LibBalsaAddressBookText *ab_text = LIBBALSA_ADDRESS_BOOK_TEXT(ab);
     GList *list;
     GList *res = NULL;
 
     if (ab->expand_aliases == FALSE)
-	return NULL;
+        return NULL;
 
     if (lbab_rubrica_load_xml(ab_rubrica, NULL) != LBABERR_OK)
-	return NULL;
+        return NULL;
 
     for (list =
-	 g_completion_complete(ab_text->name_complete, (gchar *) prefix,
-			       new_prefix); list; list = list->next) {
-	InternetAddress *ia = ((CompletionData *) list->data)->ia;
-	internet_address_ref(ia);
-	res = g_list_prepend(res, ia);
+         libbalsa_completion_complete(ab_text->name_complete,
+                                      (gchar *) prefix);
+         list; list = list->next) {
+        InternetAddress *ia = ((CompletionData *) list->data)->ia;
+        res = g_list_prepend(res, g_object_ref(ia));
     }
 
     return g_list_reverse(res);
@@ -427,7 +429,7 @@ lbab_rubrica_load_xml(LibBalsaAddressBookRubrica * ab_rubrica,
 
     g_list_foreach(ab_text->name_complete->items,
 		   (GFunc) completion_data_free, NULL);
-    g_completion_clear_items(ab_text->name_complete);
+    libbalsa_completion_clear_items(ab_text->name_complete);
 
 
     /* try to read the address book */
@@ -469,34 +471,35 @@ lbab_rubrica_load_xml(LibBalsaAddressBookRubrica * ab_rubrica,
 	    && LIBBALSA_ADDRESS_BOOK(ab_rubrica)->dist_list_mode) {
 	    /* Create a group address. */
 	    InternetAddress *ia =
-		internet_address_new_group(address->full_name);
+		internet_address_group_new(address->full_name);
+            InternetAddressGroup *group = (InternetAddressGroup *) ia;
 
 	    for (l = address->address_list; l; l = l->next) {
 		InternetAddress *member =
-		    internet_address_new_name(NULL, l->data);
-		internet_address_add_member(ia, member);
-		internet_address_unref(member);
+		    internet_address_mailbox_new(NULL, l->data);
+		internet_address_group_add_member(group, member);
+		g_object_unref(member);
 	    }
 	    cmp_data = completion_data_new(ia, address->nick_name);
 	    completion_list = g_list_prepend(completion_list, cmp_data);
-	    internet_address_unref(ia);
+	    g_object_unref(ia);
 	} else {
 	    /* Create name addresses. */
 	    GList *l;
 
 	    for (l = address->address_list; l; l = l->next) {
 		InternetAddress *ia =
-		    internet_address_new_name(address->full_name, l->data);
+		    internet_address_mailbox_new(address->full_name, l->data);
 		cmp_data = completion_data_new(ia, address->nick_name);
 		completion_list =
 		    g_list_prepend(completion_list, cmp_data);
-		internet_address_unref(ia);
+		g_object_unref(ia);
 	    }
 	}
     }
 
     completion_list = g_list_reverse(completion_list);
-    g_completion_add_items(ab_text->name_complete, completion_list);
+    libbalsa_completion_add_items(ab_text->name_complete, completion_list);
     g_list_free(completion_list);
 
     return LBABERR_OK;
