@@ -89,6 +89,7 @@
 pthread_t get_mail_thread;
 pthread_t send_mail;
 pthread_mutex_t send_messages_lock;
+int checking_mail;
 int mail_thread_pipes[2];
 int send_thread_pipes[2];
 GIOChannel *mail_thread_msg_send;
@@ -119,7 +120,7 @@ gboolean initial_open_inbox(void);
    mail because such selection cannot be stored in balsa_app and later 
    saved to the configuration file.
 */
-static gchar *cmd_line_open_mailboxes;
+static gchar **cmd_line_open_mailboxes;
 static gboolean cmd_check_mail_on_startup,
     cmd_open_unread_mailbox, cmd_open_inbox, cmd_get_stats;
 
@@ -321,8 +322,14 @@ balsa_handle_automation_options(UniqueApp * app)
         unique_app_send_message(app, COMMAND_OPEN_INBOX, NULL);
 
     if (cmd_line_open_mailboxes) {
-        UniqueMessageData *message = unique_message_data_new();
-        unique_message_data_set_text(message, cmd_line_open_mailboxes, -1);
+        gchar *join;
+        UniqueMessageData *message;
+
+        join = g_strjoinv(";", cmd_line_open_mailboxes);
+        g_strfreev(cmd_line_open_mailboxes);
+
+        message = unique_message_data_new();
+        unique_message_data_set_text(message, join, -1);
         unique_app_send_message(app, COMMAND_OPEN_MAILBOX, message);
         unique_message_data_free(message);
     }
@@ -503,7 +510,7 @@ balsa_init(int argc, char **argv)
 	 N_("Compose a new email to EMAIL@ADDRESS"), "EMAIL@ADDRESS"},
 	{"attach", 'a', 0, G_OPTION_ARG_FILENAME_ARRAY, &(attach_vect),
 	 N_("Attach file at URI"), "URI"},
-	{"open-mailbox", 'o', 0, G_OPTION_ARG_STRING,
+	{"open-mailbox", 'o', 0, G_OPTION_ARG_STRING_ARRAY,
          &(cmd_line_open_mailboxes),
 	 N_("Opens MAILBOXNAME"), N_("MAILBOXNAME")},
 	{"open-unread-mailbox", 'u', 0, G_OPTION_ARG_NONE,
@@ -779,7 +786,13 @@ scan_mailboxes_idle_cb()
 	g_idle_add((GSourceFunc) initial_open_unread_mailboxes, NULL);
 
     if (cmd_line_open_mailboxes) {
-	gchar **urls = g_strsplit(cmd_line_open_mailboxes, ";", 20);
+        gchar *join;
+	gchar **urls;
+
+        join = g_strjoinv(";", cmd_line_open_mailboxes);
+        g_strfreev(cmd_line_open_mailboxes);
+	urls = g_strsplit(join, ";", 20);
+        g_free(join);
 	g_idle_add((GSourceFunc) open_mailboxes_idle_cb, urls);
     }
 
@@ -1200,7 +1213,8 @@ balsa_cleanup(void)
        There are actually many things to do, e.g. threads should not
        be started after this point.
     */
-    if (pthread_mutex_trylock(&checking_mail_lock)) {
+    pthread_mutex_lock(&checking_mail_lock);
+    if(checking_mail) {
         /* We want to quit but there is a checking thread active.
            The alternatives are to:
            a. wait for the checking thread to finish - but it could be
@@ -1210,8 +1224,8 @@ balsa_cleanup(void)
         pthread_cancel(get_mail_thread);
         printf("Mail check thread cancelled. I know it is rough.\n");
         sleep(1);
-    } else
-        pthread_mutex_unlock(&checking_mail_lock);
+    }
+    pthread_mutex_unlock(&checking_mail_lock);
 #endif
     balsa_app_destroy();
     g_hash_table_destroy(libbalsa_mailbox_view_table);
